"hhh4" ModelThe profile log-likelihood of the log(power) parameter of the contact matrix
(see powerC) is maximized using optim.
The hhh4 fit for the optimal power value is returned with an
additional element logpower which holds information on the result of
the optimization.
fitC(object, C, normalize = TRUE, truncate = TRUE, optim.args = list(), ...)an object of class "fitC", which is an "hhh4"
object with an additional element logpower.
a model fit of class "hhh4".
the contact matrix to use.
see powerC.
a list to modify the default optimization parameters.
additional arguments for each run of update.hhh4.
Sebastian Meyer