hhh4 Fit by GroupA plot method for models with group-specific seasonality terms that are not
handled correctly by plotHHH4_season.
plotHHH4_season_groups(
x,
component = "end",
seasonStart = 1,
conf.level = 0.95,
conf.B = 999,
col = 1:6,
xlab = "time",
ylab = "multiplicative effect",
...,
refline.args = list(),
yearline.args = list(),
legend.args = list()
)a matrix of the plotted point estimates of the multiplicative seasonal effect by group.
an object of class "hhh4".
character string indicating from which component seasonality terms should be extracted.
an integer defining the epochInYear that
starts a new season (by default the first).
a confidence level for the pointwise confidence
intervals around the group-specific seasonal effects. The confidence
intervals are based on quantiles of conf.B samples from the
asymptotic multivariate normal distribution of the maximum likelihood
estimate. Alternatively, if conf.level = NA, the individual
samples are drawn instead of the confidence lines.
Set conf.level = NULL to disable confidence intervals.
a vector of group-specific colors, recycled as necessary and
passed to matplot.
arguments passed to matplot.
a list of arguments for abline to change
the style of the horizontal reference line at 1.
This line is omitted if refline.args is not a list.
a list of arguments for abline to change
the style of the line marking the end of the year at
x$stsObj@freq if seasonStart is not 1.
This line is omitted if yearline.args is not a list.
a list of arguments for legend modifying
the internal defaults. If legend.args is not a list, the legend
is omitted.